@@ -1089,8 +1089,161 @@ class TestTwitterClient(TestCase):
     # TODO: Tests for friendships_lookup()
     # TODO: Tests for friendships_incoming()
     # TODO: Tests for friendships_outgoing()
-    # TODO: Tests for friendships_create()
-    # TODO: Tests for friendships_destroy()
+
+    @inlineCallbacks
+    def test_friendships_create_by_user_id(self):
+        agent, client = self._agent_and_TwitterClient()
+        uri = 'https://api.twitter.com/1.1/friendships/create.json'
+
+        expected_params = {
+            'user_id': '2'
+        }
+
+        response_data = {
+            # Truncated user data.
+            "id": 2,
+            "id_str": "2",
+            "screen_name": "fakeuser2",
+        }
+
+        agent.add_expected_request(
+            'POST', uri, expected_params, self._resp_json(response_data))
+
+        resp = yield client.friendships_create(user_id='2')
+        self.assertEqual(resp, response_data)
+
+    @inlineCallbacks
+    def test_friendships_create_by_screen_name(self):
+        agent, client = self._agent_and_TwitterClient()
+        uri = 'https://api.twitter.com/1.1/friendships/create.json'
+
+        expected_params = {
+            'screen_name': 'fakeuser2'
+        }
+
+        response_data = {
+            # Truncated user data.
+            "id": 2,
+            "id_str": "2",
+            "screen_name": "fakeuser2",
+        }
+
+        agent.add_expected_request(
+            'POST', uri, expected_params, self._resp_json(response_data))
+
+        resp = yield client.friendships_create(screen_name='fakeuser2')
+        self.assertEqual(resp, response_data)
+
+    @inlineCallbacks
+    def test_friendships_create_follow(self):
+        agent, client = self._agent_and_TwitterClient()
+        uri = 'https://api.twitter.com/1.1/friendships/create.json'
+
+        expected_params = {
+            'screen_name': 'fakeuser2',
+            'follow': 'true'
+        }
+
+        response_data = {
+            # Truncated user data.
+            "id": 2,
+            "id_str": "2",
+            "screen_name": "fakeuser2",
+        }
+
+        agent.add_expected_request(
+            'POST', uri, expected_params, self._resp_json(response_data))
+
+        resp = yield client.friendships_create(
+            screen_name='fakeuser2', follow=True)
+        self.assertEqual(resp, response_data)
+
+    def test_friendships_create_forbidden(self):
+        agent, client = self._agent_and_TwitterClient()
+        uri = 'https://api.twitter.com/1.1/friendships/create.json'
+
+        err_dict = {
+            "errors": [{
+                "message": "Cannot find specified user.",
+                "code": 108
+            }]
+        }
+
+        agent.add_expected_request(
+            'POST', uri, {}, self._resp_json(err_dict, 403))
+
+        d = client.friendships_create()
+        d.addErrback(lambda f: f.value)
+        err = yield d
+
+        code, _phrase, body = err.args
+        self.assertEqual((403, err_dict), (code, json.loads(body)))
+
+    @inlineCallbacks
+    def test_friendships_destroy_by_user_id(self):
+        agent, client = self._agent_and_TwitterClient()
+        uri = 'https://api.twitter.com/1.1/friendships/destroy.json'
+
+        expected_params = {
+            'user_id': '2'
+        }
+
+        response_data = {
+            # Truncated user data.
+            "id": 2,
+            "id_str": "2",
+            "screen_name": "fakeuser2",
+        }
+
+        agent.add_expected_request(
+            'POST', uri, expected_params, self._resp_json(response_data))
+
+        resp = yield client.friendships_destroy(user_id='2')
+        self.assertEqual(resp, response_data)
+
+    @inlineCallbacks
+    def test_friendships_destroy_by_screen_name(self):
+        agent, client = self._agent_and_TwitterClient()
+        uri = 'https://api.twitter.com/1.1/friendships/destroy.json'
+
+        expected_params = {
+            'screen_name': 'fakeuser2'
+        }
+
+        response_data = {
+            # Truncated user data.
+            "id": 2,
+            "id_str": "2",
+            "screen_name": "fakeuser2",
+        }
+
+        agent.add_expected_request(
+            'POST', uri, expected_params, self._resp_json(response_data))
+
+        resp = yield client.friendships_destroy(screen_name='fakeuser2')
+        self.assertEqual(resp, response_data)
+
+    def test_friendships_destroy_forbidden(self):
+        agent, client = self._agent_and_TwitterClient()
+        uri = 'https://api.twitter.com/1.1/friendships/destroy.json'
+
+        err_dict = {
+            "errors": [{
+                "message": "Sorry, that page does not exist",
+                "code": 34},
+            ]
+        }
+
+        agent.add_expected_request(
+            'POST', uri, {}, self._resp_json(err_dict, 404))
+
+        d = client.friendships_destroy()
+        d.addErrback(lambda f: f.value)
+        err = yield d
+
+        code, _phrase, body = err.args
+        self.assertEqual((404, err_dict), (code, json.loads(body)))
+
     # TODO: Tests for friendships_update()
     # TODO: Tests for friendships_show()
     # TODO: Tests for friends_list()
